/**
 * 业务配置
 * */

const isDev = process.env.NODE_ENV === 'development'
const url = location.host
const isHh = location.host.includes('10.196.131.73') //是否是河海版本
const isBeta = process.env.NODE_ENV === 'development' || location.host.includes('liuwanr.cn') //是否是职站测试

const Setting = {
    /**
     * 基础配置
     * */
    // 网页标题的后缀
    titleSuffix: isHh ? '学生端' : '职站',
    // 路由模式，可选值为 history 或 hash
    routerMode: 'hash',
    // 页面切换时，是否显示模拟的进度条
    showProgressBar: true,
    // 接口请求地址
    apiBaseURL: (isDev || url.includes('liuwanr.cn')) ? 'http://www.liuwanr.cn/' : (url.includes('10.196.131.73') ? 'http://10.196.131.73/' : 'http://www.occupationlab.com/'),
    // 是否是河海版本
    isHh,
    // 学校id,河海为729,职站为2105
    schoolId: isHh ? 729 : 2105,
    // 默认系统id
    systemId: 1,
    // 子系统列表.改的时候留意要改的是哪个环境,别影响到了其他环境
    systemList: isHh ? [{
        id: 1,
        label: 'Python程序设计教学系统'
    },{
        id: 4,
        label: '经济金融建模实验教学系统'
    },{
        id: 6,
        label: '金融随机过程实验教学系统'
    },{
        id: 7,
        label: '量化投资策略建模实验教学系统'
    },{
        id: 8,
        label: '大数据分析实验教学系统'
    }] : (isBeta ? [{
        id: 1,
        label: 'Python程序设计教学系统'
    }
    // 下面这两个是川大和科大子系统,目前没有在职站开启,只有在科大川大才会开放对应的子系统
    // ,{
    //     id: 2,
    //     label: '跨国仿真系统'
    // },{
    //     id: 3,
    //     label: '期权期货系统'
    // }
    ,{
        id: 4,
        label: '经济金融建模实验教学系统'
    },{
        id: 5,
        label: 'Python可视化实验教学系统'
    },{
        id: 6,
        label: '金融随机过程实验教学系统'
    },{
        id: 7,
        label: '量化投资策略建模实验教学系统'
    },{
        id: 8,
        label: '大数据分析实验教学系统'
    },{
        id: 9,
        label: 'Python数据清洗教学实验系统'
    },{
        id: 10,
        label: 'Python数据采集（爬虫）教学实验系统'
    }] : [{
        id: 1,
        label: 'Python程序设计教学系统'
    },{
        id: 4,
        label: '经济金融建模实验教学系统'
    },{
        id: 5,
        label: 'Python可视化实验教学系统'
    },{
        id: 6,
        label: '金融随机过程实验教学系统'
    },{
        id: 7,
        label: '量化投资策略建模实验教学系统'
    },{
        id: 8,
        label: '大数据分析实验教学系统'
    },{
        id: 9,
        label: 'Python数据清洗教学实验系统'
    },{
        id: 10,
        label: 'Python数据采集（爬虫）教学实验系统'
    }]),
    // 长时间未操作，自动退出登录时间
    autoLogoutTime: 3600000,
    // 接口请求返回错误时，弹窗的持续时间，单位：秒
    modalDuration: 3,
    // 接口请求返回错误时，弹窗的类型，可选值为 Message 或 Notice
    errorModalType: 'Message',
    // Cookies 默认保存时间，单位：天
    cookiesExpires: 1,
    // token在localStorage的时间(毫秒)
    tokenExpires: 1296000000,
    /**
     * 免登录保存的token的key
     */
    tokenKey: 'oc_client_token',
    /**
     * sessionStorage里state的key
     */
    storeKey: 'oc_client_store',
    /**
     * 默认密码
     */
    initialPassword: '111aaa',
    /**
    * 多语言配置
    * */
    i18n: {
        // 默认语言
        default: 'zh',
        // 是否根据用户电脑配置自动设置语言（仅第一次有效）
        auto: false
    },
    /**
     * 布局配置
     * */
    layout: {
        
    },
    /**
     * 功能配置
     * */
    // 相同路由，不同参数间进行切换，是否强力更新
    sameRouteForceUpdate: false,
    // 是否使用动态路由
    dynamicRoute: false,
};

export default Setting;
